Crate prototext_core

Crate prototext_core 

Re-exports

pub use schema::decode_pool;
pub use schema::schema_from_pool;
pub use schema::ParsedSchema;
pub use schema::SchemaError;
pub use serialize::render_text::is_prototext_text;

Modules

decoder
helpers
instantiate
Pseudo-random protobuf instance generator for prototext instantiate-schema.
schema
serialize

Structs

RenderOpts
Options controlling how a protobuf binary payload is rendered as text.

Enums

CodecError
Errors that can occur while decoding or encoding a protobuf payload.

Functions

parse_schema
Parse a compiled .pb descriptor into a ParsedSchema.
render_as_bytes
Encode a textual prototext payload back to raw protobuf binary wire bytes.
render_as_text
Decode a raw protobuf binary payload and render it as protoc-style text.