pub fn ingest_pb(
pb_bytes: &[u8],
full_schema: &ParsedSchema,
annotations: bool,
) -> ProtoTextMessageExpand description
Decode a binary protobuf payload into a lossless ProtoTextMessage.
Mirrors decode_pb() in decode.py.
pub fn ingest_pb(
pb_bytes: &[u8],
full_schema: &ParsedSchema,
annotations: bool,
) -> ProtoTextMessageDecode a binary protobuf payload into a lossless ProtoTextMessage.
Mirrors decode_pb() in decode.py.