Module schema

Module schema 

Structs

ParsedSchema
The parsed, indexed form of a FileDescriptorSet.

Enums

SchemaError
Errors that can occur while parsing a protobuf schema descriptor.

Functions

decode_pool
Decode schema_bytes into a DescriptorPool, for use with schema_from_pool when instantiating multiple types from the same bytes.
parse_schema
Parse schema_bytes into a ParsedSchema.
schema_from_pool
Create a ParsedSchema from an already-decoded pool and a root message name.