#[non_exhaustive]pub enum SchemaError {
InvalidDescriptor(String),
MessageNotFound(String),
}Expand description
Errors that can occur while parsing a protobuf schema descriptor.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidDescriptor(String)
schema_bytes could not be decoded as a FileDescriptorSet.
MessageNotFound(String)
The requested root message was not found in the parsed descriptor.