pub fn decode_pool(schema_bytes: &[u8]) -> Result<DescriptorPool, SchemaError>Expand description
Decode schema_bytes into a DescriptorPool, for use with
schema_from_pool when instantiating multiple types from the same bytes.
pub fn decode_pool(schema_bytes: &[u8]) -> Result<DescriptorPool, SchemaError>Decode schema_bytes into a DescriptorPool, for use with
schema_from_pool when instantiating multiple types from the same bytes.